@@ -14,12 +14,16 @@ import six
 
 from pelican.log import LimitFilter
 
+
 try:
-    # SourceFileLoader is the recommended way in Python 3.3+
-    from importlib.machinery import SourceFileLoader
+    # spec_from_file_location is the recommended way in Python 3.5+
+    import importlib.util
 
     def load_source(name, path):
-        return SourceFileLoader(name, path).load_module()
+        spec = importlib.util.spec_from_file_location(name, path)
+        mod = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(mod)
+        return mod
 except ImportError:
     # but it does not exist in Python 2.7, so fall back to imp
     import imp
